# G-snip

Command line tool for Gists

## Setup

1. Get GitHub Authentication Token [Settings] -> `.tokens.ini`.

1. Copy files to Home directory

```
cp -v .tokens.ini .vimrc.more ~
```

## Usage

```
gsnip -h
```
